# Hack4U Academy Courses Library

Una biblioteca Python para consultar cursos de la academia Hack4U.

## Cursos disponibles:

- Introducción a Linux [15 horas]
- Personalización de Linux [3 horas]
- Introducción al Hacking [53 horas]

## Instalación

Instala el paquete usando `pip3`:

```python3
pip3 install hack4u


##Uso Basico
###Listar todos los cursos
```Python
from hack4u import list_courses

for course in list_courses():
    print(course)
```
